import pytest
import pandas as pd
from sqlalchemy.engine import create_engine
from src.data_sources.sql_connector import SQLConnector

@pytest.fixture
def sql_connector(mocker):
    # Mock the create_engine function from SQLAlchemy
    mock_engine = mocker.Mock()
    mocker.patch('sqlalchemy.create_engine', return_value=mock_engine)

    # Return an instance of SQLConnector with a dummy URI
    return SQLConnector('sqlite:///dummy.db'), mock_engine

def test_query_data(sql_connector):
    connector, mock_engine = sql_connector
    mock_conn = mocker.Mock()
    mock_engine.connect.return_value.__enter__.return_value = mock_conn

    # Mock the result of a query
    mock_result = pd.DataFrame({'column1': [1, 2, 3]})
    mock_conn.execute.return_value.fetchall.return_value = mock_result
    mock_conn.execute.return_value.keys.return_value = mock_result.columns

    # Perform a query using the connector
    result = connector.query_data('SELECT * FROM table')

    # Assertions to check if the query was executed and the result is as expected
    mock_engine.connect.assert_called_once()
    mock_conn.execute.assert_called_once_with('SELECT * FROM table')
    pd.testing.assert_frame_equal(result, mock_result)

# Additional tests for other methods, error handling, etc., can be added here
